@@ -22,7 +22,7 @@ import traceback
 from argparse import ArgumentParser
 from argparse import RawDescriptionHelpFormatter
 from justpy.htmlcomponents import JustpyBaseComponent
-
+from dataclasses import dataclass
 
 class App(object):
     '''
@@ -150,7 +150,7 @@ class App(object):
         clear the Error area
         '''
         self.errors.inner_html=""
-    
+
     def getLanguages(self):
         # see https://github.com/sahajsk21/Anvesha/blob/master/src/components/topnav.js
         languages= [
@@ -223,7 +223,7 @@ class App(object):
                 ["zh", "&#20013;&#25991;"],
             ]
         return languages
-        
+
     def createSelectorGroupWithLabel(self,a,text:str,classes=""):
         '''
         create a selector Group with the given label
@@ -345,18 +345,18 @@ class App(object):
          target(str): "_blank" or None
         '''
         self.menu[text]=MenuEntry(text,icon,href,target)
-        
+
 class About(jp.Div):
     """
     About Div for a given vresion
     """
-    
+
     def __init__(self,version,a,**kwargs):
         """
         construct an about Div for the given version
         """
         jp.Div.__init__(self,a=a,**kwargs)
-        
+
         jp.Div(text=f"{version.description}",a=self)
         jp.Div(text=f"version: {version.version}",a=self)
         jp.Div(text=f"updated: {version.updated}",a=self)
@@ -365,7 +365,7 @@ class About(jp.Div):
         jp.Div(inner_html=Link.create(url=version.doc_url,text="documentation",target="_blank"),a=self)
         jp.Div(inner_html=Link.create(url=version.chat_url,text="discussion",target="_blank"),a=self)
         jp.Div(inner_html=Link.create(url=version.cm_url,text="source",target="_blank"),a=self)
-    
+
 
 class MenuEntry:
     '''
@@ -406,7 +406,7 @@ class Link:
         '''
         title="" if tooltip is None else f" title='{tooltip}'"
         target="" if target is None else f" target=' {target}'"
-        style="" if style is None else f" style='{style}'" 
+        style="" if style is None else f" style='{style}'"
         link=f"<a href='{url}'{title}{target}{style}>{text}</a>"
         return link
 
@@ -443,11 +443,11 @@ class ComboBox(jp.Input):
         self.attributes.append("list")
         self.dataList=DataList(a=self)
         self.list=self.dataList.id
-        
+
 class SimpleCheckbox(jp.Div):
     """
     a simple Checkbox
-    """ 
+    """
     def __init__(self,a,labelText,classes="col-1",**kwargs):
         """
         create a simple checkbox with the given label
@@ -455,10 +455,10 @@ class SimpleCheckbox(jp.Div):
         jp.Div.__init__(self,a=a,classes=classes,data={'checked': False},**kwargs)
         self.checkbox=jp.Input(a=self,type="checkbox", classes="form-check-input",model=[self, 'checked'],**kwargs)
         self.label=jp.Label(a=self,text=labelText)
-        
+
     def check(self,checked:bool):
         self.data["checked"]=checked
-        
+
     def isChecked(self)->bool:
         return self.data["checked"]
 
@@ -519,13 +519,18 @@ class ProgressBar(jp.Div):
         """
         self.updateProgress(min(100, self.value + value))
 
+@dataclass
+class State:
+    value:bool
+
+
 class Switch(jp.Input):
     '''
     a switch
     https://mdbootstrap.com/docs/standard/forms/switch/
     '''
     
-    def __init__(self,a,labelText:str,**kwargs):
+    def __init__(self,a,labelText:str,state:State=None,div_classes:str="",**kwargs):
         '''
         construct a Switch
         
@@ -533,14 +538,32 @@ class Switch(jp.Input):
             labelText(str): the text for the label
             kwargs(): keyword arguments
         '''
-        self.div=jp.Div(a=a,classes = "form-check form-switch")
+        self.div=jp.Div(a=a,classes = f"form-check form-switch {div_classes}")
         classes="form-check-input"
         kwargs["classes"] = f"{classes} {kwargs.get('classes', '')}"
         super().__init__(a=self.div,type="checkbox",role="switch",**kwargs)
-        switchLabel=jp.Span(a=self.div,text=labelText,classes="form-check-label")
-        #switchLabel.for_component(self)
-        # <input class="form-check-input" type="checkbox" role="switch" id="flexSwitchCheckDefault" />
-        #<label class="form-check-label" for="flexSwitchCheckDefault">Default switch checkbox input</label>
+        if state:
+            self.state=state
+            self.checked=self.state.value
+            self.on("input",self.onChangeState)
+
+        self.switchLabel = jp.Label(
+                a=self.div,
+                text=labelText,
+                classes="form-check-label"
+        )
+        self.switchLabel.for_component = self
+
+    def onChangeState(self,msg):
+        self.state.value=msg.checked
+
+    def update_label(self, label:str):
+        """
+        update the label of the switch
+        Args:
+            label: new label of the switch
+        """
+        self.switchLabel.text = label
 
 class IconButton(jp.Button):
     '''
